package WebService::Mattermost::V4::API::Object::Role::Description;

# ABSTRACT: Adds a "description" field to an object.

use Moo::Role;
use Types::Standard qw(Maybe Str);

################################################################################

has description => (is => 'ro', isa => Maybe[Str], lazy => 1, builder => 1);

################################################################################

sub _build_description {
    my $self = shift;

    return $self->raw_data->{description};
}

################################################################################

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

WebService::Mattermost::V4::API::Object::Role::Description - Adds a "description" field to an object.

=head1 VERSION

version 0.24

=head1 DESCRIPTION

Attach a description to a v4::Object object.

=head2 ATTRIBUTES

=over 4

=item C<description>

=back

=head1 AUTHOR

Mike Jones <mike@netsplit.org.uk>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2020 by Mike Jones.

This is free software, licensed under:

  The MIT (X11) License

=cut
